==> huaweicloudsdkaos-3.1.53-py2.py3-none-any.whl: huaweicloudsdkaos/v1/model/show_template_version_content_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowTemplateVersionContentResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'location': 'str'
    }

    attribute_map = {
        'location': 'Location'
    }

    def __init__(self, location=None):
        """ShowTemplateVersionContentResponse

        The model defined in huaweicloud sdk

        :param location: 
        :type location: str
        """
        
        super(ShowTemplateVersionContentResponse, self).__init__()

        self._location = None
        self.discriminator = None

        if location is not None:
            self.location = location

    @property
    def location(self):
        """Gets the location of this ShowTemplateVersionContentResponse.

        :return: The location of this ShowTemplateVersionContentResponse.
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this ShowTemplateVersionContentResponse.

        :param location: The location of this ShowTemplateVersionContentResponse.
        :type location: str
        """
        self._location = location

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowTemplateVersionContentResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkaos-3.1.132-py2.py3-none-any.whl: huaweicloudsdkaos/v1/model/show_template_version_content_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowTemplateVersionContentResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'body': 'str',
        'location': 'str'
    }

    attribute_map = {
        'body': 'body',
        'location': 'Location'
    }

    def __init__(self, body=None, location=None):
        """ShowTemplateVersionContentResponse

        The model defined in huaweicloud sdk

        :param body: 空响应体
        :type body: str
        :param location: 
        :type location: str
        """
        
        super(ShowTemplateVersionContentResponse, self).__init__()

        self._body = None
        self._location = None
        self.discriminator = None

        if body is not None:
            self.body = body
        if location is not None:
            self.location = location

    @property
    def body(self):
        """Gets the body of this ShowTemplateVersionContentResponse.

        空响应体

        :return: The body of this ShowTemplateVersionContentResponse.
        :rtype: str
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this ShowTemplateVersionContentResponse.

        空响应体

        :param body: The body of this ShowTemplateVersionContentResponse.
        :type body: str
        """
        self._body = body

    @property
    def location(self):
        """Gets the location of this ShowTemplateVersionContentResponse.

        :return: The location of this ShowTemplateVersionContentResponse.
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this ShowTemplateVersionContentResponse.

        :param location: The location of this ShowTemplateVersionContentResponse.
        :type location: str
        """
        self._location = location

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowTemplateVersionContentResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
